"""ConfPrint Python printer configuration tool."""

from confprint.err_print import err_print  # noqa
from confprint.prefix_printer import prefix_printer  # noqa


# This is automatically set using the bumpversion tool.
# Version of the confprint package
__version__ = "0.3.0"
